OC.L10N.register(
    "notes",
    {
    "Notes" : "Muistiinpanot",
    "The last viewed note cannot be accessed. " : "Ei pääsyä viimeksi katsottuun muistiinpanoon.",
    "The notes folder is not accessible: %s" : "Ei pääsyä muistiinpanokansioon: %s",
    "Error" : "Virhe",
    "New note" : "Uusi muistiinpano",
    "Settings" : "Asetukset",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
    "path to notes" : "polku muistiinpanoihin",
    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
    "All notes" : "Kaikki muistiinpanot",
    "Categories" : "Luokat",
    "No search result for “{search}” in {category}" : "Ei tuloksia haulla “{search}” luokasta {category}",
    "No search result for “{search}”" : "Ei tuloksia haulla “{search}”",
    "Loading …" : "Ladataan…",
    "Search result for “{search}” in {category}" : "Tulos haulle “{search}” luokasta {category}",
    "Search result for “{search}”" : "Tulos haulle “{search}”",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "This week" : "Tällä viikolla",
    "Last week" : "Viime viikolla",
    "This month" : "Tässä kuussa",
    "Last month" : "Viime kuussa",
    "Rename" : "Nimeä uudelleen",
    "Delete note" : "Poista muistiinpano",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Empty note" : "Tyhjä muistiinpano",
    "Write …" : "Kirjoita…",
    "Details" : "Tiedot",
    "Preview" : "Esikatselu",
    "Edit" : "Muokkaa",
    "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
    "Set category" : "Aseta luokka",
    "Category" : "Luokka",
    "Uncategorized" : "Luokittelematon",
    "Click here to save manually" : "Napsauta tästä tallentaaksesi manuaalisesti",
    "Saving failed!" : "Tallentaminen epäonnistui!",
    "Last modified: {date}" : "Viimeksi muokattu: {date}",
    "Note has unsaved changes" : "Muistiinpanossa ei ole tallentamattomia muutoksia",
    "Subcategory" : "Aliluokka",
    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Updating settings has failed." : "Asetusten päivittäminen epäonnistui.",
    "Fetching notes has failed." : "Muistiinpanojen noutaminen epäonnistui.",
    "Fetching note {id} has failed." : "Muistiinpanon {id} noutaminen epäonnistui.",
    "Creating new note has failed." : "Uuden muistiinpanon luominen epäonnistui.",
    "Updating note {id} has failed." : "Muistiinpanon {id} päivittäminen epäonnistui.",
    "Deleting note {id} has failed." : "Muistiinpanon {id} poistaminen epäonnistui."
},
"nplurals=2; plural=(n != 1);");
